############
Contributing
############

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

Please read the instructions `here <https://nephila.github.io/contributing/contributing>`_ to start contributing to `django-meta`.
